@@ -25,6 +25,14 @@ parser.add_argument("-e", "--errors", help="Expected number of errors", type=int
 parser.add_argument(
     "-i", "--ignore", help="files and folders to exclude. Seperated by comma ','"
 )
+parser.add_argument(
+    "-s",
+    "--silent",
+    "-q",
+    "--quiet",
+    help="Hide all non error related log messages",
+    action="store_true",
+)
 args = parser.parse_args()
 
 
@@ -49,8 +57,10 @@ global error_count
 
 
 file_ignore_list = [
-    # Ignore node module folders
-    "\\node_modules\\",
+    # Ignore node module and rooms xml folders
+    "**\\node_modules\\**",
+    "**\\resources\\rooms\\**",
+    "**\\content\\rooms\\**",
     # Both of these files do not have a top-level tag, so they will always fail linting.
     # (The game's internal XML parser does not care about this.)
     "fxlayers.xml",
@@ -78,6 +88,10 @@ ignore_files = []
 if args.ignore is not None:
     file_ignore_list.extend(args.ignore.split(","))
 
+silent_mode = False
+if args.silent:
+    silent_mode = True
+
 
 # ~~~~~~~~~~~~ Special conditions ~~~~~~~~~~~~
 
@@ -111,11 +125,12 @@ def clear_isaac_refs_recursive(node):
 
 
 def printf(*args):
-    print(*args, flush=True)
+    if not silent_mode:
+        print(*args, flush=True)
 
 
 def print_err(string):
-    printf(bcolors.FAIL + str(string) + bcolors.ENDC)
+    print(bcolors.FAIL + str(string) + bcolors.ENDC, flush=True)
 
 
 def print_ok(string):
@@ -123,7 +138,7 @@ def print_ok(string):
 
 
 def print_warn(string):
-    printf(bcolors.WARNING + str(string) + bcolors.ENDC)
+    print(bcolors.WARNING + str(string) + bcolors.ENDC, flush=True)
 
 
 def is_valid_xml(file_path):
@@ -152,17 +167,28 @@ def get_gitignore_files():
 def main():
     printf("--- " + __package__ + " --- Version:", __version__)
 
+    read_github_env_vars()
+
     global root_folder, expected_error_count, recursive, error_count
     total_error_count = 0
 
     files = glob.glob(root_folder + "/**.xml", recursive=recursive)
     # remove files and folders to ignore
     for ignoreFile in file_ignore_list:
-        files = [f for f in files if ignoreFile not in f]
+        if not ignoreFile.startswith("*"):  # single file entry support
+            ignoreFile = "\\" + ignoreFile
+        ignoredFiles = glob.glob(root_folder + ignoreFile, recursive=True)
+        files = [f for f in files if f not in ignoredFiles]
 
     # if exists, remove all folders and files mentioned in the .gitignore file
-    for git_ignore_file in get_gitignore_files():
-        files = [f for f in files if git_ignore_file not in f]
+    gitignore_files = get_gitignore_files()
+    if len(gitignore_files) > 0:
+        printf(
+            f"Found a .gitignore file. Using it to ignore additional {len(gitignore_files)} files and directories:"
+        )
+        printf(f"{gitignore_files}")
+        for git_ignore_file in gitignore_files:
+            files = [f for f in files if git_ignore_file not in f]
 
     printf(f"Found {len(files)} files in path: {root_folder}/**.xml")
 
@@ -212,7 +238,7 @@ def main():
             print_err("Expected error count was not reached!")
             sys.exit(1)
     else:
-        print_ok("No errors found")
+        print_ok("No errors found.")
 
 
 def evaluate_special_conditions(xml_file_path: str):
@@ -279,5 +305,4 @@ def read_github_env_vars():
 
 
 if __name__ == "__main__":
-    read_github_env_vars()
     main()
